@@ -17,4 +17,8 @@ from .operators import *
 from .sed import *
 from .extlaws import *
 from .likelihoods import *
-    # from .interfaces import *
\ No newline at end of file
+
+__all__ += sed.__all__
+__all__ += extlaws.__all__
+__all__ += operators.__all__
+__all__ += likelihoods.__all__
\ No newline at end of file
